Screenshots
===========

.. figure:: ../../tests/robotframework/screenshots/search.png
   :class: sosse-screenshot

   :doc:`Search results <user/search>`

.. raw:: html

   <br/>

.. figure:: ../../tests/robotframework/screenshots/cache_screenshot.png
   :class: sosse-screenshot

   :doc:`Cached page with screenshots <user/cached>`

.. raw:: html

   <br/>

.. figure:: ../../tests/robotframework/screenshots/statistics.png
   :class: sosse-screenshot

   :doc:`Index statistics <user/statistics>`

.. raw:: html

   <br/>

.. figure:: ../../tests/robotframework/screenshots/history.png
   :class: sosse-screenshot

   :doc:`Search history <user/history>`

.. raw:: html

   <br/>

.. figure:: ../../tests/robotframework/screenshots/crawl_status.png
   :class: sosse-screenshot

   :doc:`Real-time crawling status <crawl/status>`

.. raw:: html

   <br/>

.. figure:: ../../tests/robotframework/screenshots/crawl_policy_decision_no_hilight.png
   :class: sosse-screenshot

   :doc:`Crawl Policies setup <crawl/policies>`

.. raw:: html

   <br/>

.. figure:: ../../tests/robotframework/screenshots/browsable_home.png
   :class: sosse-screenshot

   :doc:`Archive browsing <archive>`
